//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

/*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************
	*/

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
    using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
    
	using System.Text;
	using System.Runtime.InteropServices;
	
    public partial class CustomMarshal
    {
		[DllImport("coredll.dll", SetLastError = true)]
		private static extern IntPtr LocalAlloc(LOCALMEMORYFLAGS uFlags, uint Bytes);

		[DllImport("coredll.dll", SetLastError = true)]
		private static extern IntPtr LocalFree(IntPtr hMem);

		[Flags]
		public enum LOCALMEMORYFLAGS
		{
			LMEM_FIXED = 0x0000,
			LMEM_MOVEABLE = 2,
			LMEM_ZEROINIT = 0x0040,
			LPTR = (LMEM_FIXED | LMEM_ZEROINIT)
		}   

		#region Get functions

		#region IntPtr
		public static IntPtr GetIntPtr(IntPtr ptr, int ofs)
		{
			int i = CustomMarshal.GetInt32(ptr,ofs);
			return new IntPtr(i);
		}
		#endregion

		#region Int32
		public static Int32 GetInt32(IntPtr ptr, int ofs)
		{
			byte[] data = new byte[4];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, 4);

			return BitConverter.ToInt32(data,0);
		}

		public static UInt32 GetUInt32(IntPtr ptr, int ofs)
		{
			byte[] data = new byte[4];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, 4);

			return BitConverter.ToUInt32(data,0);
		}
		#endregion

		#region Int16
		public static Int16 GetInt16(IntPtr ptr, int ofs)
		{
			byte[] data = new byte[2];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, 2);

			return BitConverter.ToInt16(data,0);
		}

		public static UInt16 GetUInt16(IntPtr ptr, int ofs)
		{
			byte[] data = new byte[2];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, 2);

			return BitConverter.ToUInt16(data,0);
		}
		#endregion

		#region String
		public static string PtrToStringUni(IntPtr ptr, int ofs, int len)
		{
			int cb = len * Marshal.SystemDefaultCharSize;
			byte[] data = new byte[cb];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, cb);

			string s = Encoding.Unicode.GetString(data, 0, len);
			
			int nullpos = s.IndexOf('\0');
			if(nullpos > -1)
				s = s.Substring(0,nullpos);

			return s;
		}

		public static string PtrToStringAscii(IntPtr ptr, int ofs, int len)
		{
			int cb = len;
			byte[] data = new byte[cb];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, cb);

			string s = Encoding.ASCII.GetString(data, 0, len);
			
			int nullpos = s.IndexOf('\0');
			if(nullpos > -1)
				s = s.Substring(0,nullpos);

			return s;
		}
		#endregion

		#region Char
		public static char GetChar(IntPtr ptr, int ofs)
		{
			byte[] data = new byte[Marshal.SystemDefaultCharSize];
			Marshal.Copy(new IntPtr((int)ptr + ofs),data, 0, data.Length);

			return BitConverter.ToChar(data,0);
		}
		#endregion

		#region Byte[]
		public static byte[] GetByteArray(IntPtr ptr, int ofs, int len)
		{
			byte[] data = new byte[len];
			Marshal.Copy(new IntPtr((int)ptr + ofs), data, 0, len);

			return data;
		}
		#endregion

		#endregion

		#region Helper Functions

		public static IntPtr AllocHLocal(uint cb)
		{
			return LocalAlloc(LOCALMEMORYFLAGS.LPTR, cb);
		}

		public static void FreeHLocal(IntPtr hMem)
		{
			if (hMem != IntPtr.Zero)
			{
				LocalFree(hMem);
			}
		}
		
		public static DateTime Time_tToDateTime(uint time_t) 
		{
			long win32FileTime = 10000000*(long)time_t + 116444736000000000;
			return DateTime.FromFileTimeUtc(win32FileTime);
		}

		#endregion
    }
}
