//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

/*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************
	*/

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
    using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
        
	using System.Collections.Generic;
	using System.ComponentModel;
	using System.Data;
	using System.Text;
	using System.Net;
	using Microsoft.Win32;
	using System.IO;
	using System.Runtime.InteropServices;    	
    
    public partial class IPSettings
    {
		private const UInt32 HKEY_CLASSES_ROOT = 0x80000000;
		private const UInt32 HKEY_CURRENT_USER = 0x80000001;
		private const UInt32 HKEY_LOCAL_MACHINE = 0x80000002;
		private const UInt32 HKEY_USERS = 0x80000003;

		private const int    WS_EX_NODRAG = 0x40000000;
		private const int    GWL_EXSTYLE = -20;
		
		private const int PORT1 = 1;
		private const int PORT2 = 2;
		
		[DllImport("Coredll", EntryPoint = "RegFlushKey")]
		private static extern Int32 RegFlushKey(UInt32 key);		

		private static void FlushRegistry()
		{
			RegFlushKey(HKEY_CLASSES_ROOT);
			RegFlushKey(HKEY_CURRENT_USER);
			RegFlushKey(HKEY_LOCAL_MACHINE);
			RegFlushKey(HKEY_USERS);
		}		
		
		/// <summary>
		/// Set IP configuration for a specific port
		/// </summary>
		/// <param name="PanelType">Panel type number 0-T/K, 1-TA/TxB, 2-TxA</param>
		/// <param name="portNo">Hardware port number - 1 or 2</param>
		/// <param name="addr">IP-address</param>
		/// <param name="subnetMask">Subnet mask</param>
		/// <param name="gateway">Gateway address</param>
		/// <param name="dns1">Primary DNS</param>
		/// <param name="dns2">Secondary DNS</param>
		/// <param name="dhcp">Use DHCP - true or false</param>
		/// <returns>true if adapter is found</returns>
		public static bool SetPort(int PanelType,int portNo,string addr, string subnetMask, string gateway, string dns1, string dns2,bool dhcp)
		{
			if (Environment.OSVersion.Platform == PlatformID.WinCE)
			{
				string adapterName = NetControl.GetAdapterName(PanelType, portNo);
			
				if (adapterName != string.Empty)
				{				
					NetControl.AdapterSetReg(adapterName, addr, subnetMask, gateway, dns1, dns2, dhcp);
					NetControl.RebindAdapter(adapterName);
					FlushRegistry();
					return true;
				}				
			}			
			return false;
		}
		
		/// <summary>
		/// Get IP configuration for a specific port
		/// </summary>
		/// <param name="PanelType">Panel type number 0-T/K, 1-TA/TxB, 2-TxA</param>
		/// <param name="portNo">Hardware port number - 1 or 2</param>
		/// <param name="addr">IP-address</param>
		/// <param name="subnetMask">Subnet mask</param>
		/// <param name="gateway">Gateway address</param>
		/// <param name="dns1">Primary DNS</param>
		/// <param name="dns2">Secondary DNS</param>
		/// <param name="dhcp">Use DHCP - true or false</param>/// <returns></returns>
		/// <returns>nonzero if adapter is found</returns>
		public static bool GetPort(int PanelType, int portNo,ref string addr, ref string subnetMask, ref string gateway, ref string dns1, ref string dns2,ref bool dhcp)
		{
			if (Environment.OSVersion.Platform == PlatformID.WinCE)
			{
				string adapterName = NetControl.GetAdapterName(PanelType, portNo);
				return( NetControl.AdapterGetReg(adapterName, ref addr, ref subnetMask, ref gateway, ref dns1, ref dns2, ref dhcp) );			
			}
			return false;
		}
    }
}
